@@ -1,9 +1,9 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-# Time-stamp: "2021-12-12 14:45:57 (ywatanabe)"
+# Time-stamp: "2022-11-01 18:46:25 (ywatanabe)"
 
 
-from catboost import CatBoostClassifier
+# from catboost import CatBoostClassifier
 from sklearn.discriminant_analysis import QuadraticDiscriminantAnalysis
 from sklearn.ensemble import AdaBoostClassifier
 from sklearn.gaussian_process import GaussianProcessClassifier
