@@ -1,11 +1,13 @@
 #!/usr/bin/env python3
 
-from . import plt, layer, optim, act, utils
+from . import act, clustering, layer, metrics, optim, plt, sk, utils
+from .ClassificationReporter import (
+    ClassificationReporter,
+    MultiClassificationReporter,
+)
+from .ClassifierServer import ClassifierServer
+from .EarlyStopping import EarlyStopping
 from .LearningCurveLogger import LearningCurveLogger
 
-from .ClassificationReporter import ClassificationReporter
-
-from .ClassifierServer import ClassifierServer
 # from ._switchers import switch_layer, switch_act, switch_optim
 from .loss.MultiTaskLoss import MultiTaskLoss
-from .EarlyStopping import EarlyStopping
