@@ -1,7 +1,8 @@
-from ._verify_n_gpus import verify_n_gpus
-from ._merge_labels import merge_labels
-from ._get_params import get_params
-from ._under_sample import under_sample
+from ._check_params import check_params
 from ._DefaultDataset import DefaultDataset
-
 from ._format_samples_for_sktime import format_samples_for_sktime
+from ._LabelEncoder import LabelEncoder
+from ._merge_labels import merge_labels
+from ._sliding_window_data_augmentation import sliding_window_data_augmentation
+from ._under_sample import under_sample
+from ._verify_n_gpus import verify_n_gpus
